@@ -11,21 +11,24 @@ setMethod(
   signature(object = "hspec"),
   definition = function(object, mark = mark, type = type, inter_arrival = inter_arrival,
                         N = N, Nc = Nc,
-                        alpha = alpha, beta = beta, ...){
+                        mu = mu, alpha = alpha, beta = beta,
+                        lambda = NULL, lambda_component = NULL, lambda_component_n = NULL,
+                        ...){
 
     dimens <- object@dimens
 
     # parameter setting
     if (is.function(object@mu)){
       if(length(formals(object@mu)) == 1){
-        mu <- evalf(object@mu)
+        mu0 <- evalf(object@mu)
       } else {
-        mu <- mu(n = 1, mark = mark, type = type, inter_arrival = inter_arrival,
-                 N = N, Nc = Nc,
-                 alpha = alpha, beta = beta)
+        mu0 <- mu(n = 1, mark = mark, type = type, inter_arrival = inter_arrival,
+                  N = N, Nc = Nc, lambda = lambda, lambda_component = lambda_component,
+                  lambda_component_n = lambda_component_n,
+                  alpha = alpha, beta = beta)
       }
     } else{
-      mu <- object@mu
+      mu0 <- object@mu
     }
     if (is.function(object@alpha)){
       alpha <- evalf(object@alpha)
@@ -44,8 +47,17 @@ setMethod(
       LAMBDA0 <- matrix(lamb0, nrow=1)
 
     } else {
-      LAMBDA_st <- solve(diag(dimens) - alpha / beta) %*% mu
-      LAMBDA0 <- matrix(rep(LAMBDA_st, dimens), nrow=dimens, byrow=T) * alpha / beta
+      # need to handle when the matrix is singular
+      LAMBDA0 <- matrix(rep(0, dimens^2), nrow=dimens)
+      LAMBDA0 <- tryCatch({
+          LAMBDA_st <- solve(diag(dimens) - alpha / beta) %*% mu0
+          matrix(rep(LAMBDA_st, dimens), nrow=dimens, byrow=T) * alpha / beta
+        },
+        error = function(e){
+          warning("Due to the singualr martrix in caculcation, set initial value of lambda to mu.")
+          matrix(rep(0, dimens^2), nrow=dimens)
+        }
+      )
     }
     LAMBDA0
   }
